==> java-symbol-solver-core-0.2-sources.jar: me/tomassetti/symbolsolver/javassistmodel/contexts/JavassistMethodContext.java <==
package me.tomassetti.symbolsolver.javassistmodel.contexts;

import javassist.CtClass;
import javassist.CtMethod;
import me.tomassetti.symbolsolver.model.declarations.MethodDeclaration;
import me.tomassetti.symbolsolver.model.declarations.TypeDeclaration;
import me.tomassetti.symbolsolver.model.declarations.ValueDeclaration;
import me.tomassetti.symbolsolver.model.typesystem.TypeUsage;
import me.tomassetti.symbolsolver.model.resolution.Context;
import me.tomassetti.symbolsolver.model.resolution.SymbolReference;
import me.tomassetti.symbolsolver.model.resolution.TypeSolver;

import java.util.List;
import java.util.Optional;

@Deprecated
public class JavassistMethodContext implements Context {

    private CtMethod wrappedNode;

    public JavassistMethodContext(CtMethod wrappedNode) {
        this.wrappedNode = wrappedNode;
    }

    @Override
    public SymbolReference<ValueDeclaration> solveSymbol(String name, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public SymbolReference<TypeDeclaration> solveType(String name, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public Optional<TypeUsage> solveGenericType(String name, TypeSolver typeSolver) {
        // TODO consider generic parameters of the method
        return getParent().solveGenericType(name, typeSolver);
    }

    @Override
    public SymbolReference<MethodDeclaration> solveMethod(String name, List<TypeUsage> parameterTypes, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public Context getParent() {
        CtClass ctClass = wrappedNode.getDeclaringClass();
        return new JavassistClassContext(ctClass);
    }

}

==> java-symbol-solver-core-0.3.1-sources.jar: me/tomassetti/symbolsolver/javassistmodel/contexts/JavassistMethodContext.java <==
package me.tomassetti.symbolsolver.javassistmodel.contexts;

import javassist.CtClass;
import javassist.CtMethod;
import me.tomassetti.symbolsolver.model.declarations.MethodDeclaration;
import me.tomassetti.symbolsolver.model.declarations.TypeDeclaration;
import me.tomassetti.symbolsolver.model.declarations.ValueDeclaration;
import me.tomassetti.symbolsolver.model.usages.typesystem.Type;
import me.tomassetti.symbolsolver.core.resolution.Context;
import me.tomassetti.symbolsolver.model.resolution.SymbolReference;
import me.tomassetti.symbolsolver.model.resolution.TypeSolver;

import java.util.List;
import java.util.Optional;

@Deprecated
public class JavassistMethodContext implements Context {

    private CtMethod wrappedNode;

    public JavassistMethodContext(CtMethod wrappedNode) {
        this.wrappedNode = wrappedNode;
    }

    @Override
    public SymbolReference<ValueDeclaration> solveSymbol(String name, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public SymbolReference<TypeDeclaration> solveType(String name, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public Optional<Type> solveGenericType(String name, TypeSolver typeSolver) {
        // TODO consider generic typeParametersValues of the method
        return getParent().solveGenericType(name, typeSolver);
    }

    @Override
    public SymbolReference<MethodDeclaration> solveMethod(String name, List<Type> argumentsTypes, TypeSolver typeSolver) {
        throw new UnsupportedOperationException();
    }

    @Override
    public Context getParent() {
        CtClass ctClass = wrappedNode.getDeclaringClass();
        return new JavassistClassContext(ctClass);
    }

}
